@@ -2,10 +2,10 @@ package Rose::DB::Object::Metadata::Column::Serial;
 
 use strict;
 
-use Rose::DB::Object::Metadata::Column::Scalar;
-our @ISA = qw(Rose::DB::Object::Metadata::Column::Scalar);
+use Rose::DB::Object::Metadata::Column::Integer;
+our @ISA = qw(Rose::DB::Object::Metadata::Column::Integer);
 
-our $VERSION = '0.01';
+our $VERSION = '0.60';
 
 sub type { 'serial' }
 
